@@ -1,10 +1,9 @@
 import responses
-from UnleashClient.constants import FEATURES_URL
+from UnleashClient.constants import FEATURES_URL, ETAG
 from UnleashClient.periodic_tasks import fetch_and_load_features
 from UnleashClient.features import Feature
 from tests.utilities.mocks.mock_features import MOCK_FEATURE_RESPONSE, MOCK_FEATURE_RESPONSE_PROJECT
-from tests.utilities.testing_constants import URL, APP_NAME, INSTANCE_ID, CUSTOM_HEADERS, CUSTOM_OPTIONS, DEFAULT_STRATEGY_MAPPING, PROJECT_URL, PROJECT_NAME
-from tests.utilities.decorators import cache_empty  # noqa: F401
+from tests.utilities.testing_constants import URL, APP_NAME, INSTANCE_ID, CUSTOM_HEADERS, CUSTOM_OPTIONS, DEFAULT_STRATEGY_MAPPING, PROJECT_URL, PROJECT_NAME, ETAG_VALUE
 
 
 FULL_FEATURE_URL = URL + FEATURES_URL
@@ -14,7 +13,7 @@ FULL_FEATURE_URL = URL + FEATURES_URL
 def test_fetch_and_load(cache_empty):  # noqa: F811
     # Set up for tests
     in_memory_features = {}
-    responses.add(responses.GET, FULL_FEATURE_URL, json=MOCK_FEATURE_RESPONSE, status=200)
+    responses.add(responses.GET, FULL_FEATURE_URL, json=MOCK_FEATURE_RESPONSE, status=200, headers={'etag': ETAG_VALUE})
     temp_cache = cache_empty
 
     fetch_and_load_features(URL,
@@ -27,6 +26,7 @@ def test_fetch_and_load(cache_empty):  # noqa: F811
                             DEFAULT_STRATEGY_MAPPING)
 
     assert isinstance(in_memory_features["testFlag"], Feature)
+    assert temp_cache.get(ETAG) == ETAG_VALUE
 
 
 @responses.activate
